@@ -4,7 +4,7 @@ package DBQuery;
 
 use DBI;
 
-$DBQuery::VERSION = 0.004;
+$DBQuery::VERSION = 0.005;
 
 sub new
 {
@@ -25,13 +25,11 @@ sub new
 	{
 		$DB->{driver_name} = 'mysql' unless (defined $DB->{driver_name});
 		$DB->{driver_name} = ucfirst($DB->{driver_name}) if ($DB->{driver_name} eq "oracle");
-#	$DB->{db_port} = 3306 unless (defined $DB->{db_port});
-#	$DB->{db_sock} = '/tmp/mysql.sock' unless (defined $DB->{db_sock});
 		$self = {
 			'dsn' => $DB->{driver_name} eq 'mysql'
 				? 'dbi:' . $DB->{driver_name} . ':database=' . $DB->{db_name} . ';' .
 				(defined $DB->{db_host} ? 'host=' . $DB->{db_host} . ';' : '') .
-				(defined $DB->{db_sock} ? 'mysql_socket=' . $DB->{db_sock} . ';' : 'mysql_socket=/tmp/mysql.sock;') . 
+				(defined $DB->{db_sock} ? 'mysql_socket=' . $DB->{db_sock} . ';' : 'mysql_socket=/var/lib/mysql/mysql.sock;') . 
 				(defined $DB->{db_port} ? 'port=' . $DB->{db_port} : 'port=3306') 
 				: ($DB->{driver_name} eq 'pgsql' 
 						? 'dbi:' . $DB->{driver_name} . ':dbname=' . $DB->{db_name} . ';' . 
@@ -316,6 +314,8 @@ I<Mon Jun 29 16:56:02 2009> B<v0.003> Can miss out the arg: db_host, and optimiz
 
 I<Tue Jun 30 17:31:44 2009> B<v0.004> Modify the test case.
 
+I<Tue Jul 07 10:19:28 2009> B<v0.005> Repair and pass test.
+
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
